package bigloo;

public class cobj
{
}
